==> greenbone-security-assistant_24.5.0.orig.tar.gz: gsa-24.5.0/src/web/entity/hooks/__tests__/useEntityDelete.test.js <==
/* SPDX-FileCopyrightText: 2025 Greenbone AG
 *
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */

import {describe, test, expect, testing} from '@gsa/testing';
import useEntityDelete from 'web/entity/hooks/useEntityDelete';
import {rendererWith, wait} from 'web/utils/Testing';

describe('useEntityDelete', () => {
  test('should allow to delete an entity', async () => {
    const entity = {id: '123'};
    const deleteEntity = testing.fn().mockResolvedValue(entity);
    const gmp = {
      foo: {delete: deleteEntity},
    };
    const onDeleted = testing.fn();
    const onDeleteError = testing.fn();
    const onInteraction = testing.fn();
    const {renderHook} = rendererWith({gmp, store: true});
    const {result} = renderHook(() =>
      useEntityDelete('foo', {
        onDeleted,
        onDeleteError,
        onInteraction,
      }),
    );
    expect(result.current).toBeDefined;
    result.current(entity);
    await wait();
    expect(deleteEntity).toHaveBeenCalledWith(entity);
    expect(onDeleted).toHaveBeenCalledOnce();
    expect(onDeleteError).not.toHaveBeenCalled();
    expect(onInteraction).toHaveBeenCalledOnce();
  });

  test('should call onDeleteError when deleting an entity fails', async () => {
    const deleteEntity = testing.fn().mockRejectedValue(new Error('error'));
    const entity = {id: '123'};
    const gmp = {
      foo: {delete: deleteEntity},
    };
    const onDeleted = testing.fn();
    const onDeleteError = testing.fn();
    const onInteraction = testing.fn();
    const {renderHook} = rendererWith({gmp, store: true});
    const {result} = renderHook(() =>
      useEntityDelete('foo', {
        onDeleted,
        onDeleteError,
        onInteraction,
      }),
    );
    expect(result.current).toBeDefined;
    result.current(entity);
    await wait();
    expect(deleteEntity).toHaveBeenCalledWith(entity);
    expect(onDeleted).not.toHaveBeenCalled();
    expect(onDeleteError).toHaveBeenCalledOnce();
    expect(onInteraction).toHaveBeenCalledOnce();
  });
});

==> greenbone-security-assistant_24.6.1.orig.tar.gz: gsa-24.6.1/src/web/entity/hooks/__tests__/useEntityDelete.test.js <==
/* SPDX-FileCopyrightText: 2025 Greenbone AG
 *
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */

import {describe, test, expect, testing} from '@gsa/testing';
import useEntityDelete from 'web/entity/hooks/useEntityDelete';
import {rendererWith, wait} from 'web/utils/Testing';

describe('useEntityDelete', () => {
  test('should allow to delete an entity', async () => {
    const entity = {id: '123'};
    const deleteEntity = testing.fn().mockResolvedValue(entity);
    const gmp = {
      foo: {delete: deleteEntity},
    };
    const onDeleted = testing.fn();
    const onDeleteError = testing.fn();
    const onInteraction = testing.fn();
    const {renderHook} = rendererWith({gmp, store: true});
    const {result} = renderHook(() =>
      useEntityDelete('foo', {
        onDeleted,
        onDeleteError,
        onInteraction,
      }),
    );
    expect(result.current).toBeDefined();
    result.current(entity);
    await wait();
    expect(deleteEntity).toHaveBeenCalledWith(entity);
    expect(onDeleted).toHaveBeenCalledOnce();
    expect(onDeleteError).not.toHaveBeenCalled();
    expect(onInteraction).toHaveBeenCalledOnce();
  });

  test('should call onDeleteError when deleting an entity fails', async () => {
    const deleteEntity = testing.fn().mockRejectedValue(new Error('error'));
    const entity = {id: '123'};
    const gmp = {
      foo: {delete: deleteEntity},
    };
    const onDeleted = testing.fn();
    const onDeleteError = testing.fn();
    const onInteraction = testing.fn();
    const {renderHook} = rendererWith({gmp, store: true});
    const {result} = renderHook(() =>
      useEntityDelete('foo', {
        onDeleted,
        onDeleteError,
        onInteraction,
      }),
    );
    expect(result.current).toBeDefined();
    result.current(entity);
    await wait();
    expect(deleteEntity).toHaveBeenCalledWith(entity);
    expect(onDeleted).not.toHaveBeenCalled();
    expect(onDeleteError).toHaveBeenCalledOnce();
    expect(onInteraction).toHaveBeenCalledOnce();
  });
});
